Package: hmmm
Version: 1.0-5
Date: 2024-05-08
Title: Hierarchical Multinomial Marginal Models
Authors@R: c(person("Roberto", "Colombi", role = c("aut", "cre"), email = "colombi@unibg.it"), person("Sabrina", "Giordano", email = "sabrina.giordano@unical.it", role = "aut"),person("Manuela", "Cazzaro", role = "aut", email = "manuela.cazzaro@unimib.it"),person("Joseph", "Lang", role = "ctb", email = "joseph-lang@uiowa.edu"))
Description: Functions for specifying and fitting marginal models for contingency tables proposed by Bergsma and Rudas (2002) <doi:10.1214/aos/1015362188> here called hierarchical multinomial marginal models (hmmm) and their extensions presented by Bartolucci, Colombi and Forcina (2007) <https://www.jstor.org/stable/24307737>; multinomial Poisson homogeneous (mph) models and homogeneous linear predictor (hlp) models for contingency tables proposed by Lang (2004) <doi:10.1214/aos/1079120140> and Lang (2005) <doi:10.1198/016214504000001042>. Inequality constraints on the parameters are allowed and can be tested.
Imports: quadprog, MASS, mvtnorm, nleqslv, methods
License: GPL (>= 2)
Repository: CRAN
URL: https://www.r-project.org
NeedsCompilation: no
Packaged: 2024-05-09 10:27:29 UTC; rcolombi
Author: Roberto Colombi [aut, cre],
  Sabrina Giordano [aut],
  Manuela Cazzaro [aut],
  Joseph Lang [ctb]
Maintainer: Roberto Colombi <colombi@unibg.it>
Date/Publication: 2024-05-13 08:43:15 UTC
Built: R 4.6.0; ; 2026-04-26 19:51:14 UTC; unix
