export(create.XMAT,
hmmm.chibar,
hmmm.mlfit,
hmmm.model,
hmmm.model.X,
mphineq.fit,
recursive,
marg.list,
loglin.model,
getnames,
akaike,
GMI,
inv_GMI
)
S3method(print,hmmmmod)
S3method(summary,hmmmmod)
S3method(print,hmmmfit)
S3method(summary,hmmmfit)
S3method(anova,hmmmfit)
S3method(print,hmmmchibar)
S3method(summary,hmmmchibar)
S3method(print,mphfit)
S3method(summary,mphfit)
import(MASS)
import(mvtnorm)
import(nleqslv)
import(quadprog)
importFrom("graphics", "abline", "matplot")
importFrom("stats", "as.formula", "contr.treatment", "contrasts",
             "contrasts<-", "model.matrix", "optimize", "pchisq",
             "pnorm", "qchisq", "quantile", "rnorm", "runif", "terms",
             "uniroot", "xtabs")
importFrom("utils", "combn")
importFrom("methods", "is")
importFrom("stats", "na.omit")